# OCRD Browser

An extensible viewer for [OCRD](https://ocr-d.de/) mets.xml files 

## Screenshot

![OCRD Browser with two image and one xml view](docs/screenshot.png)

## Installation

```
pip install browse-ocrd
```
